
--Copyright (c) 1993 Ohio Board of Regents and the University of
--Cincinnati.  All Rights Reserved.

--instantiations of design entity "place" with input and output arcs
--bound and identified with distinct names.  the particular design
--entities provided below follow a naming convention of:
--
--place_X_Y: where X denotes the number of input arcs with names
--           in_arc1, in_arc2, ... in_arcX; and
--           where Y denotes the number of output arcs with names
--           out_arc1, out_arc2, ... out_arcY.

--by default, the instantiations are created with generics denoting:
--  an initial marking of zero tokens,
--  a blank name, and
--  with debuging that enables the reporting of token movement.

library petri;
use work.petri.all;
entity place_0_1 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (out_arc1 : inout arc bus);
    
end;


architecture structure of place_0_1 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

    signal open_port : arc := (not_driving, 0);

begin

P1 : place 

     generic map (number_in_arcs  => 0,
                  number_out_arcs => 1,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (out_arc(1) => out_arc1);

end;


library work;
use work.petri.all;
entity place_0_2 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (out_arc1, out_arc2 : inout arc bus);
    
end;


architecture structure of place_0_2 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

    signal open_port : arc := (not_driving, 0);

begin

P1 : place 

     generic map (number_in_arcs  => 0,
                  number_out_arcs => 2,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2);

end;


library work;
use work.petri.all;
entity place_0_3 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (out_arc1, out_arc2, out_arc3 : inout arc bus);
    
end;


architecture structure of place_0_3 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

    signal open_port : arc := (not_driving, 0);

begin

P1 : place 

     generic map (number_in_arcs  => 0,
                  number_out_arcs => 3,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2,
                  out_arc(3) => out_arc3);

end;


library work;
use work.petri.all;
entity place_0_4 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (out_arc1, out_arc2, out_arc3, out_arc4 : inout arc bus);
    
end;


architecture structure of place_0_4 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

    signal open_port : arc := (not_driving, 0);

begin

P1 : place 

     generic map (number_in_arcs  => 0,
                  number_out_arcs => 4,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2,
                  out_arc(3) => out_arc3,
                  out_arc(4) => out_arc4);

end;


library work;
use work.petri.all;
entity place_1_0 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (in_arc1            : inout arc bus);
    
end;


architecture structure of place_1_0 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

    signal open_port : arc := (not_driving, 0);

begin

P1 : place 

     generic map (number_in_arcs  => 1,
                  number_out_arcs => 0,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1);

end;


library work;
use work.petri.all;
entity place_1_1 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (in_arc1            : inout arc bus;
          out_arc1           : inout arc bus);
    
end;


architecture structure of place_1_1 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

begin

P1 : place 

     generic map (number_in_arcs  => 1,
                  number_out_arcs => 1,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  out_arc(1) => out_arc1);

end;


library work;
use work.petri.all;
entity place_1_2 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (in_arc1            : inout arc bus;
          out_arc1, out_arc2 : inout arc bus);
    
end;


architecture structure of place_1_2 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

begin

P1 : place 

     generic map (number_in_arcs  => 1,
                  number_out_arcs => 2,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2);

end;

library work;
use work.petri.all;
entity place_1_3 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (in_arc1                      : inout arc bus;
          out_arc1, out_arc2, out_arc3 : inout arc bus);
    
end;


architecture structure of place_1_3 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

begin

P1 : place 

     generic map (number_in_arcs  => 1,
                  number_out_arcs => 3,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  out_arc(1) => out_arc1, out_arc(2) => out_arc2,
                  out_arc(3) => out_arc3);

end;


library work;
use work.petri.all;
entity place_2_0 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (in_arc1,  in_arc2  : inout arc bus);

    
end;


architecture structure of place_2_0 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

    signal open_port : arc := (not_driving, 0);

begin

P1 : place 

     generic map (number_in_arcs  => 2,
                  number_out_arcs => 0,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  in_arc(2)  => in_arc2);

end;


library work;
use work.petri.all;
entity place_2_1 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (in_arc1,  in_arc2  : inout arc bus;
          out_arc1           : inout arc bus);
    
end;


architecture structure of place_2_1 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

begin

P1 : place 

     generic map (number_in_arcs  => 2,
                  number_out_arcs => 1,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  in_arc(2)  => in_arc2,
                  out_arc(1) => out_arc1);

end;


library work;
use work.petri.all;
entity place_2_2 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (in_arc1,  in_arc2  : inout arc bus;
          out_arc1, out_arc2 : inout arc bus);
    
end;


architecture structure of place_2_2 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

begin

P1 : place 

     generic map (number_in_arcs  => 2,
                  number_out_arcs => 2,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  in_arc(2)  => in_arc2,
                  out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2);

end;

library work;
use work.petri.all;
entity place_3_1 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (in_arc1, in_arc2, in_arc3 : inout arc bus;
          out_arc1                  : inout arc bus);
    
end;


architecture structure of place_3_1 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

begin

P1 : place 

     generic map (number_in_arcs  => 3,
                  number_out_arcs => 1,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  in_arc(2) => in_arc2,
                  in_arc(3) => in_arc3,
                  out_arc(1) => out_arc1);

end;

library work;
use work.petri.all;
entity place_3_2 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (in_arc1, in_arc2, in_arc3 : inout arc bus;
          out_arc1, out_arc2        : inout arc bus);
    
end;


architecture structure of place_3_2 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

begin

P1 : place 

     generic map (number_in_arcs  => 3,
                  number_out_arcs => 2,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  in_arc(2)  => in_arc2,
                  in_arc(3)  => in_arc3,
                  out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2);

end;

library work;
use work.petri.all;
entity place_3_4 is

    generic (initial_marking : integer := 0;
             place_name      : string  := "";
             debug_cntrl     : debug   := trace_tokens);

    port (in_arc1, in_arc2, in_arc3 		 : inout arc bus;
          out_arc1, out_arc2, out_arc3, out_arc4 : inout arc bus);
    
end;


architecture structure of place_3_4 is

component place

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             initial_tokens  : integer;
             pl_name         : string;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : place use entity work.place(behavior);

begin

P1 : place 

     generic map (number_in_arcs  => 3,
                  number_out_arcs => 4,
		  initial_tokens  => initial_marking, 
		  pl_name         => place_name,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  in_arc(2)  => in_arc2,
                  in_arc(3)  => in_arc3,
                  out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2,
		  out_arc(3) => out_arc3,
	          out_arc(4) => out_arc4);

end;



