
--Copyright (c) 1993 Ohio Board of Regents and the University of
--Cincinnati.  All Rights Reserved.

--instantiations of design entity "transition" with input and output
--arcs bound and identified with distinct names.  the particular
--design entities provided below follow a naming convention of:
--
--transition_X_Y: where X denotes the number of input arcs with names
--                in_arc1, in_arc2, ... in_arcX; and
--                where Y denotes the number of output arcs with names
--                out_arc1, out_arc2, ... out_arcY.

--by default, the instantiations are created with generics denoting:
--  a blank name, and
--  with debuging that enables the reporting of transition firing.


library petri;
use petri.petri.all;
use petri.math.all;

entity transition_1_1 is

    generic (transition_name : string  := "";
             debug_cntrl     : debug   := firing);

    port (in_arc1            : inout arc bus;
          out_arc1	     : inout arc bus);
    
end;


architecture structure of transition_1_1 is

component transition

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             trans_name      : string;
	     petri_type      : p_type;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : transition use entity work.transition(behavior);

begin

P1 : transition 

     generic map (number_in_arcs  => 1,
                  number_out_arcs => 1,
		  trans_name      => transition_name,
	          petri_type      => live,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  out_arc(1) => out_arc1);

end;

library petri;
use petri.petri.all;
entity transition_1_2 is

    generic (transition_name : string  := "";
             debug_cntrl     : debug   := firing);

    port (in_arc1            : inout arc bus;
          out_arc1, out_arc2 : inout arc bus);
    
end;


architecture structure of transition_1_2 is

component transition

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             trans_name      : string;
	     petri_type      : p_type;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : transition use entity work.transition(behavior);

begin

P1 : transition 

     generic map (number_in_arcs  => 1,
                  number_out_arcs => 2,
		  trans_name      => transition_name,
	          petri_type      => live,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2);

end;


library petri;
use petri.petri.all;
entity transition_1_3 is

    generic (transition_name : string  := "";
             debug_cntrl     : debug   := firing);

    port (in_arc1                       : inout arc bus;
          out_arc1, out_arc2, out_arc3  : inout arc bus);
    
end;


architecture structure of transition_1_3 is

component transition

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             trans_name      : string;
	     petri_type      : p_type;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : transition use entity work.transition(behavior);

begin

P1 : transition 

     generic map (number_in_arcs  => 1,
                  number_out_arcs => 3,
		  trans_name      => transition_name,
	          petri_type      => live,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2,
                  out_arc(3) => out_arc3);

end;

library petri;
use petri.petri.all;
entity transition_1_4 is

    generic (transition_name : string  := "";
             debug_cntrl     : debug   := firing);

    port (in_arc1            : inout arc bus;
          out_arc1, out_arc2,
          out_arc3, out_arc4 : inout arc bus);
    
end;


architecture structure of transition_1_4 is

component transition

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             trans_name      : string;
	     petri_type      : p_type;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : transition use entity work.transition(behavior);

begin

P1 : transition 

     generic map (number_in_arcs  => 1,
                  number_out_arcs => 4,
		  trans_name      => transition_name,
	          petri_type      => live,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2,
                  out_arc(3) => out_arc3,
                  out_arc(4) => out_arc4);

end;

library work;
use work.petri.all;
entity transition_2_1 is

    generic (transition_name : string  := "";
             debug_cntrl     : debug   := firing);

    port (in_arc1,  in_arc2  : inout arc bus;
          out_arc1           : inout arc bus);
    
end;


architecture structure of transition_2_1 is

component transition

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             trans_name      : string;
	     petri_type      : p_type;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : transition use entity work.transition(behavior);

begin

P1 : transition 

     generic map (number_in_arcs  => 2,
                  number_out_arcs => 1,
		  trans_name      => transition_name,
	          petri_type      => live,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  in_arc(2)  => in_arc2,
                  out_arc(1) => out_arc1);

end;


library work;
use work.petri.all;
entity transition_2_2 is

    generic (transition_name : string  := "";
             debug_cntrl     : debug   := firing);

    port (in_arc1,  in_arc2  : inout arc bus;
          out_arc1, out_arc2 : inout arc bus);
    
end;


architecture structure of transition_2_2 is

component transition

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             trans_name      : string;
	     petri_type      : p_type;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : transition use entity work.transition(behavior);

begin

P1 : transition 

     generic map (number_in_arcs  => 2,
                  number_out_arcs => 2,
		  trans_name      => transition_name,
	          petri_type      => live,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  in_arc(2)  => in_arc2,
                  out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2);

end;


library work;
use work.petri.all;
entity transition_3_1 is

    generic (transition_name : string  := "";
             debug_cntrl     : debug   := firing);

    port (in_arc1,  in_arc2,  in_arc3  : inout arc bus;
          out_arc1                     : inout arc bus);
    
end;


architecture structure of transition_3_1 is

component transition

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             trans_name      : string;
	     petri_type      : p_type;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : transition use entity work.transition(behavior);

begin

P1 : transition 

     generic map (number_in_arcs  => 3,
                  number_out_arcs => 1,
		  trans_name      => transition_name,
	          petri_type      => live,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  in_arc(2)  => in_arc2,
                  in_arc(3)  => in_arc3,
                  out_arc(1) => out_arc1);

end;

library petri;
use petri.petri.all;
entity transition_5_2 is

    generic (transition_name : string  := "";
             debug_cntrl     : debug   := firing);

    port (in_arc1, in_arc2,
          in_arc3, in_arc4,
          in_arc5            : inout arc bus;
          out_arc1, out_arc2 : inout arc bus);
    
end;


architecture structure of transition_5_2 is

component transition

    generic (number_in_arcs  : integer;
             number_out_arcs : integer;
             trans_name      : string;
	     petri_type      : p_type;
             debug_control   : debug);

    port (in_arc  : inout arc_array (1 to number_in_arcs) bus;
          out_arc : inout arc_array (1 to number_out_arcs) bus);

end component;


for P1 : transition use entity work.transition(behavior);

begin

P1 : transition 

     generic map (number_in_arcs  => 5,
                  number_out_arcs => 2,
		  trans_name      => transition_name,
	          petri_type      => live,
		  debug_control   => debug_cntrl)

     port map    (in_arc(1)  => in_arc1,
                  in_arc(2)  => in_arc2,
                  in_arc(3)  => in_arc3,
                  in_arc(4)  => in_arc4,
                  in_arc(5)  => in_arc5,
                  out_arc(1) => out_arc1,
                  out_arc(2) => out_arc2);

end;
